==> jc-1.4.0.tar.gz: javax/naming/StringRefAddr.c <==
// public class javax.naming.StringRefAddr

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 505b8a9a6675be0 java_lang_NullPointerException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr
// @dep_class f5863fde17a5b812 javax_naming_StringRefAddr

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_NullPointerException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable
// @dep_header javax_naming_StringRefAddr

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/NullPointerException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"
#include "javax/naming/StringRefAddr.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_naming_StringRefAddr$initial_value$serialVersionUID = _JC_JLONG(-8913762495138505527);
static _jc_field _jc_javax_naming_StringRefAddr$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_naming_StringRefAddr$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_StringRefAddr$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_naming_StringRefAddr$initial_value$serialVersionUID,
};

// private final java.lang.String contents
static _jc_field _jc_javax_naming_StringRefAddr$field_info$contents = {
	.name=		"contents",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_naming_StringRefAddr$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_StringRefAddr$object, refs[-1].javax_naming_StringRefAddr.contents),
};

// Fields
static _jc_field *const _jc_javax_naming_StringRefAddr$fields[] = {
	&_jc_javax_naming_StringRefAddr$field_info$serialVersionUID,
	&_jc_javax_naming_StringRefAddr$field_info$contents
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_javax_naming_StringRefAddr$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_javax_naming_StringRefAddr$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_naming_StringRefAddr$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_naming_StringRefAddr$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_javax_naming_StringRefAddr$type,
	.param_types=		&_jc_javax_naming_StringRefAddr$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_naming_StringRefAddr$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_StringRefAddr$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_naming_StringRefAddr$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_StringRefAddr, _init$a34354cd9552963f);

void
_jc_javax_naming_StringRefAddr$method$_init$a34354cd9552963f(_jc_env *const env, _jc_javax_naming_StringRefAddr$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_javax_naming_StringRefAddr$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_NullPointerException$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_VMThrowable$object *r6;

	r0 = this;
	r1 = param0;
	r2 = param1;
	if (r1 != _JC_NULL)
		goto label0;
	r3 = _JC_NEW(env, java_lang_NullPointerException);
	r4 = _JC_STRING(env, "addrType cannot be null");
	_JC_REF_FIELD(env, r3, java_lang_Throwable, cause) = r3;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r3);
	_JC_REF_FIELD(env, r3, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, detailMessage) = r4;
	_JC_THROW(env, r3);

label0:
	_JC_REF_FIELD(env, r0, javax_naming_RefAddr, addrType) = r1;
	_JC_LINE_NUMBER(65);				// 0
	_JC_REF_FIELD(env, r0, javax_naming_StringRefAddr, contents) = r2;
	_JC_LINE_NUMBER(66);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object getContent()
//

static _jc_linenum _jc_javax_naming_StringRefAddr$linenum_table$getContent$3271597a0076ff68[];

static const unsigned char _jc_javax_naming_StringRefAddr$param_ptypes$getContent$3271597a0076ff68[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_naming_StringRefAddr$method_info$getContent$3271597a0076ff68 = {
	.name=			"getContent",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_javax_naming_StringRefAddr$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_javax_naming_StringRefAddr$param_ptypes$getContent$3271597a0076ff68,
	.signature_hash=	_JC_JLONG(0x3271597a0076ff68),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_naming_StringRefAddr$vtable, javax_naming_StringRefAddr.getContent$3271597a0076ff68) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_naming_StringRefAddr$linenum_table$getContent$3271597a0076ff68
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_StringRefAddr, getContent$3271597a0076ff68);

_jc_java_lang_Object$object *
_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68(_jc_env *const env, _jc_javax_naming_StringRefAddr$object *this)
{
	struct _jc_javax_naming_StringRefAddr$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(73);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_naming_StringRefAddr, contents);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_naming_StringRefAddr$methods[] = {
	&_jc_javax_naming_StringRefAddr$method_info$_init$a34354cd9552963f,
	&_jc_javax_naming_StringRefAddr$method_info$getContent$3271597a0076ff68
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_naming_StringRefAddr$fields_struct _jc_javax_naming_StringRefAddr$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_18[] = {
	&_jc_javax_naming_StringRefAddr$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_24[] = {
	&_jc_javax_naming_RefAddr$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_naming_StringRefAddr$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[18]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_18,
	[24]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_24,
	[65]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_65,
	[113]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_naming_StringRefAddr$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/NullPointerException",	_JC_JLONG(0x505b8a9a6675be0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "javax/naming/RefAddr",	_JC_JLONG(0x1aa52b9631354f18) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_naming_StringRefAddr$vtype _jc_javax_naming_StringRefAddr$type = {
    .type= {
	.name=			"javax/naming/StringRefAddr",
	.superclass=		&_jc_javax_naming_RefAddr$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0xf5863fde17a5b812),
		.source_file=		"StringRefAddr.java",
		.instance_size=		sizeof(_jc_javax_naming_StringRefAddr$refs) + sizeof(_jc_javax_naming_StringRefAddr$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_javax_naming_StringRefAddr$fields) / sizeof(*_jc_javax_naming_StringRefAddr$fields),
		.fields=		_jc_javax_naming_StringRefAddr$fields,
		.num_methods=		sizeof(_jc_javax_naming_StringRefAddr$methods) / sizeof(*_jc_javax_naming_StringRefAddr$methods),
		.methods=		_jc_javax_naming_StringRefAddr$methods,
		.instanceof_hash_table=	_jc_javax_naming_StringRefAddr$instanceof_hash_table,
		.class_fields=		&_jc_javax_naming_StringRefAddr$class_fields,
		.num_class_depends=		sizeof(_jc_javax_naming_StringRefAddr$class_depends) / sizeof(*_jc_javax_naming_StringRefAddr$class_depends),
		.class_depends=		_jc_javax_naming_StringRefAddr$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_javax_naming_RefAddr$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_javax_naming_RefAddr$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_naming_RefAddr$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_naming_RefAddr= {
	    .equals$8a15e0625571c581=
		&_jc_javax_naming_RefAddr$method$equals$8a15e0625571c581,
	    .getContent$3271597a0076ff68=			// overridden
		&_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68,
	    .getType$1756580bdd350fe6=
		&_jc_javax_naming_RefAddr$method$getType$1756580bdd350fe6,
	    .hashCode$53152098849316df=
		&_jc_javax_naming_RefAddr$method$hashCode$53152098849316df,
	    .toString$7ea43b33b80a3070=
		&_jc_javax_naming_RefAddr$method$toString$7ea43b33b80a3070,
	},
	.javax_naming_StringRefAddr= {
	    .getContent$3271597a0076ff68=
		&_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/naming/StringRefAddr.c <==
// public class javax.naming.StringRefAddr

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 505b8a9a6675be0 java_lang_NullPointerException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr
// @dep_class f5863fde17a5b812 javax_naming_StringRefAddr

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_NullPointerException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable
// @dep_header javax_naming_StringRefAddr

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/NullPointerException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"
#include "javax/naming/StringRefAddr.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_naming_StringRefAddr$initial_value$serialVersionUID = _JC_JLONG(-8913762495138505527);
static _jc_field _jc_javax_naming_StringRefAddr$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_naming_StringRefAddr$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_StringRefAddr$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_naming_StringRefAddr$initial_value$serialVersionUID,
};

// private final java.lang.String contents
static _jc_field _jc_javax_naming_StringRefAddr$field_info$contents = {
	.name=		"contents",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_naming_StringRefAddr$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_StringRefAddr$object, refs[-1].javax_naming_StringRefAddr.contents),
};

// Fields
static _jc_field *const _jc_javax_naming_StringRefAddr$fields[] = {
	&_jc_javax_naming_StringRefAddr$field_info$serialVersionUID,
	&_jc_javax_naming_StringRefAddr$field_info$contents
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_javax_naming_StringRefAddr$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_javax_naming_StringRefAddr$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_naming_StringRefAddr$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_naming_StringRefAddr$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_javax_naming_StringRefAddr$type,
	.param_types=		&_jc_javax_naming_StringRefAddr$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_naming_StringRefAddr$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_StringRefAddr$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_naming_StringRefAddr$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_StringRefAddr, _init$a34354cd9552963f);

void _JC_JCNI_ATTR
_jc_javax_naming_StringRefAddr$method$_init$a34354cd9552963f(_jc_env *const env, _jc_javax_naming_StringRefAddr$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_javax_naming_StringRefAddr$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_NullPointerException$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_VMThrowable$object *r6;

	r0 = this;
	r1 = param0;
	r2 = param1;
	if (r1 != _JC_NULL)
		goto label0;
	r3 = _JC_NEW(env, java_lang_NullPointerException);
	r4 = _JC_STRING(env, "addrType cannot be null");
	_JC_REF_FIELD(env, r3, java_lang_Throwable, cause) = r3;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r3);
	_JC_REF_FIELD(env, r3, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, detailMessage) = r4;
	_JC_THROW(env, r3);

label0:
	_JC_REF_FIELD(env, r0, javax_naming_RefAddr, addrType) = r1;
	_JC_LINE_NUMBER(65);				// 0
	_JC_REF_FIELD(env, r0, javax_naming_StringRefAddr, contents) = r2;
	_JC_LINE_NUMBER(66);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object getContent()
//

static _jc_linenum _jc_javax_naming_StringRefAddr$linenum_table$getContent$3271597a0076ff68[];

static const unsigned char _jc_javax_naming_StringRefAddr$param_ptypes$getContent$3271597a0076ff68[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_naming_StringRefAddr$method_info$getContent$3271597a0076ff68 = {
	.name=			"getContent",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_javax_naming_StringRefAddr$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_javax_naming_StringRefAddr$param_ptypes$getContent$3271597a0076ff68,
	.signature_hash=	_JC_JLONG(0x3271597a0076ff68),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_naming_StringRefAddr$vtable, javax_naming_StringRefAddr.getContent$3271597a0076ff68) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_naming_StringRefAddr$linenum_table$getContent$3271597a0076ff68
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_StringRefAddr, getContent$3271597a0076ff68);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68(_jc_env *const env, _jc_javax_naming_StringRefAddr$object *this)
{
	struct _jc_javax_naming_StringRefAddr$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(73);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_naming_StringRefAddr, contents);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_naming_StringRefAddr$methods[] = {
	&_jc_javax_naming_StringRefAddr$method_info$_init$a34354cd9552963f,
	&_jc_javax_naming_StringRefAddr$method_info$getContent$3271597a0076ff68
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_naming_StringRefAddr$fields_struct _jc_javax_naming_StringRefAddr$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_18[] = {
	&_jc_javax_naming_StringRefAddr$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_24[] = {
	&_jc_javax_naming_RefAddr$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_StringRefAddr$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_naming_StringRefAddr$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[18]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_18,
	[24]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_24,
	[65]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_65,
	[101]=	_jc_javax_naming_StringRefAddr$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_naming_StringRefAddr$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/NullPointerException",	_JC_JLONG(0x505b8a9a6675be0) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "javax/naming/RefAddr",	_JC_JLONG(0x1aa52b9631354f18) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_naming_StringRefAddr$vtype _jc_javax_naming_StringRefAddr$type = {
    .type= {
	.name=			"javax/naming/StringRefAddr",
	.superclass=		&_jc_javax_naming_RefAddr$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0xf5863fde17a5b812),
		.source_file=		"StringRefAddr.java",
		.instance_size=		sizeof(_jc_javax_naming_StringRefAddr$refs) + sizeof(_jc_javax_naming_StringRefAddr$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_javax_naming_StringRefAddr$fields) / sizeof(*_jc_javax_naming_StringRefAddr$fields),
		.fields=		_jc_javax_naming_StringRefAddr$fields,
		.num_methods=		sizeof(_jc_javax_naming_StringRefAddr$methods) / sizeof(*_jc_javax_naming_StringRefAddr$methods),
		.methods=		_jc_javax_naming_StringRefAddr$methods,
		.instanceof_hash_table=	_jc_javax_naming_StringRefAddr$instanceof_hash_table,
		.class_fields=		&_jc_javax_naming_StringRefAddr$class_fields,
		.num_class_depends=		sizeof(_jc_javax_naming_StringRefAddr$class_depends) / sizeof(*_jc_javax_naming_StringRefAddr$class_depends),
		.class_depends=		_jc_javax_naming_StringRefAddr$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_javax_naming_RefAddr$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_javax_naming_RefAddr$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_naming_RefAddr$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_naming_RefAddr= {
	    .equals$8a15e0625571c581=
		&_jc_javax_naming_RefAddr$method$equals$8a15e0625571c581,
	    .getContent$3271597a0076ff68=			// overridden
		&_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68,
	    .getType$1756580bdd350fe6=
		&_jc_javax_naming_RefAddr$method$getType$1756580bdd350fe6,
	    .hashCode$53152098849316df=
		&_jc_javax_naming_RefAddr$method$hashCode$53152098849316df,
	    .toString$7ea43b33b80a3070=
		&_jc_javax_naming_RefAddr$method$toString$7ea43b33b80a3070,
	},
	.javax_naming_StringRefAddr= {
	    .getContent$3271597a0076ff68=
		&_jc_javax_naming_StringRefAddr$method$getContent$3271597a0076ff68,
	},
    }
};
